* [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Microservice Discovery in Your CI/CD Pipeline](https://help.sap.com/docs/leanix/ea/microservice-discovery-in-your-ci-cd-pipeline)
  * Configuring Your CI/CD Pipeline
